/*******************************************************************************
 System Interrupts File

  File Name:
    system_interrupt.c

  Summary:
    Raw ISR definitions.

  Description:
    This file contains a definitions of the raw ISRs required to support the
    interrupt sub-system.

  Summary:
    This file contains source code for the interrupt vector functions in the
    system.

  Description:
    This file contains source code for the interrupt vector functions in the
    system.  It implements the system and part specific vector "stub" functions
    from which the individual "Tasks" functions are called for any modules
    executing interrupt-driven in the MPLAB Harmony system.

  Remarks:
    This file requires access to the systemObjects global data structure that
    contains the object handles to all MPLAB Harmony module objects executing
    interrupt-driven in the system.  These handles are passed into the individual
    module "Tasks" functions to identify the instance of the module to maintain.
 *******************************************************************************/

// DOM-IGNORE-BEGIN
/*******************************************************************************
Copyright (c) 2011-2014 released Microchip Technology Inc.  All rights reserved.

Microchip licenses to you the right to use, modify, copy and distribute
Software only when embedded on a Microchip microcontroller or digital signal
controller that is integrated into your product or third party product
(pursuant to the sublicense terms in the accompanying license agreement).

You should refer to the license agreement accompanying this Software for
additional information regarding your rights and obligations.

SOFTWARE AND DOCUMENTATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER
CONTRACT, NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR
OTHER LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR
CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF
SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
(INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
 *******************************************************************************/
// DOM-IGNORE-END

// *****************************************************************************
// *****************************************************************************
// Section: Included Files
// *****************************************************************************
// *****************************************************************************

#include "system/common/sys_common.h"
#include "app.h"
#include "system_definitions.h"

#include "stdio.h"



int ix;
char Data[128];
char DeviceNum[10][128];
int jx;
//int Flag_Sw; 
int Flag_centData;  //ZgiPCj̃f[^otO
int Flag_Sw1;
extern int ScanMode;

// *****************************************************************************
// *****************************************************************************
// Section: System Interrupt Vector Functions
// *****************************************************************************
// *****************************************************************************
 

 
void __ISR(_I2C5_MASTER_VECTOR, ipl1AUTO) _IntHandlerDrvI2CMasterInstance0(void)
{
    DRV_I2C_Tasks(sysObj.drvI2C0);
}
    

void __ISR(_I2C5_BUS_VECTOR, ipl1AUTO) _IntHandlerDrvI2CErrorInstance0(void)
    {
    SYS_ASSERT(false, "I2C Driver Instance 0 Error");
}

        
    
    
 
 
 

 




  
void __ISR(_UART3_TX_VECTOR, ipl3AUTO) _IntHandlerDrvUsartTransmitInstance0(void)
{
    DRV_USART_TasksTransmit(sysObj.drvUsart0);
}
void __ISR(_UART3_RX_VECTOR, ipl3AUTO) _IntHandlerDrvUsartReceiveInstance0(void)
{
     char tempChar;
    
       
    if (PLIB_USART_ReceiverDataIsAvailable(USART_ID_3)) //Mf[^L̏ꍇ
    //if(U3STAbits.URXDA == 1)   //Mf[^L̏ꍇ    //Receive buffer has data, at least one more character can be read
    {
        tempChar = U3RXREG; //RN4020̕ԐMlǂݍ
        Write_Byte2(tempChar);  //Tera Termւ̕\
        Data[ix] = tempChar;    //LN^tɕ\邽߈ꎞf[^ۑ
        
        if((Data[ix - 1] == '\r') && (tempChar == '\n'))//\r\n: LF(s)̏ꍇAData[]Zbg@
        {
           Data[ix + 1] = '\0';     //Data[0]....Data[ix]𕶎
           Flag_centData = 1;   //ZgiPCj̃f[^o
           if(ScanMode == 1)       //XL[h
                    /////    (Data[12] == ',') && (Data[14] == ',') ) //ԂȂȂ̂NG   //XXXXXXXXXXXXX,X,   //12byte,X, 
           {
               jx++;
               sprintf(&DeviceNum[jx][0],"%s",&Data[0]);    //Data[] DeviceNum[jx][]]ɃRs[
           }
           else jx = 0;
           
           ix = 0;
        }    
        else ix++;

    }
    
 //   PLIB_INT_SourceFlagClear(INT_ID_0, INT_SOURCE_USART_3_RECEIVE);
    IFS4bits.U3RXIF = 0;    //RX݃tONA
    
    DRV_USART_TasksReceive(sysObj.drvUsart0);
}
void __ISR(_UART3_FAULT_VECTOR, ipl3AUTO) _IntHandlerDrvUsartErrorInstance0(void)
    {
    DRV_USART_TasksError(sysObj.drvUsart0);
}
     
        
        
 
void __ISR(_UART4_TX_VECTOR, ipl1AUTO) _IntHandlerDrvUsartTransmitInstance1(void)
{
    DRV_USART_TasksTransmit(sysObj.drvUsart1);
    }
void __ISR(_UART4_RX_VECTOR, ipl1AUTO) _IntHandlerDrvUsartReceiveInstance1(void)
{
    DRV_USART_TasksReceive(sysObj.drvUsart1);
}
void __ISR(_UART4_FAULT_VECTOR, ipl1AUTO) _IntHandlerDrvUsartErrorInstance1(void)
{
    DRV_USART_TasksError(sysObj.drvUsart1);
}
 
 

 

 

 

 
    void __ISR(_CHANGE_NOTICE_A_VECTOR, ipl1AUTO) _IntHandlerChangeNotification_PortA(void)
{
     //SW1  RA4 at mikroBus]{[h DB004
    if(PORTAbits.RA4 == 0)  //SW1 ONo
    {                      
        delay_ms(30);
        if(PORTAbits.RA4 == 0)Flag_Sw1 = 1;
    }
    
    PLIB_INT_SourceFlagClear(INT_ID_0,INT_SOURCE_CHANGE_NOTICE_A);
}
    
    
 
void __ISR(_TIMER_1_VECTOR, ipl1AUTO) IntHandlerDrvTmrInstance0(void)
    {
    DRV_TMR_Tasks(sysObj.drvTmr0);
    }
/*******************************************************************************
 End of File
*/
